=======
Credits
=======

Development Lead
----------------

* David Huard <huard.david@ouranos.ca> `@huard <https://github.com/huard>`_

Contributors
------------

* Christian Jauvin <jauvin.christian@ouranos.ca> `@cjauvin <https://github.com/cjauvin>`_
* Trevor James Smith <smith.trevorj@ouranos.ca> `@Zeitsperre <https://github.com/Zeitsperre>`_
* Julie Mai <juliane.mai@uwaterloo.ca> `@julemai <https://github.com/julemai>`_
* Ming Han <ming.han@uwaterloo.ca> `@dustming <https://github.com/dustming>`_
